==> ropenaq_0.1.0.tar.gz: ropenaq/inst/doc/mapping_openaq_monitors.R <==
## ---- echo = FALSE, warning=FALSE, message=FALSE-------------------------
NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  purl = NOT_CRAN,
  eval = NOT_CRAN
)

## ---- warning=FALSE, message=FALSE---------------------------------------
library("ggplot2")
library("ropenaq")
library("dplyr")

## ---- warning=FALSE, message=FALSE---------------------------------------
dataGeo <- rbind(ropenaq::aq_locations(limit = 1000, page = 1)$results,
                 ropenaq::aq_locations(limit = 1000, page = 2)$results,
                 ropenaq::aq_locations(limit = 1000, page = 3)$results)
dataGeo <- filter(dataGeo, location != "Test Prueba", location != "PA")

## ----fig.width=7, fig.height=4, warning=FALSE, message=FALSE-------------


library("rworldmap")

worldMap <- map_data(map="world")

gg <- ggplot() + geom_map(data=worldMap, map=worldMap,
                          aes(map_id=region, x=long, y=lat),
                          fill = "grey60")
gg

## ----fig.width=7, fig.height=4-------------------------------------------
plotMap <- gg +
  geom_point(data = dataGeo, aes(x=longitude, y=latitude), size=1, col = "#EE9F8E")+
  theme(axis.line=element_blank(),axis.text.x=element_blank(),
       axis.text.y=element_blank(),axis.ticks=element_blank(),
       axis.title.x=element_blank(),
       axis.title.y=element_blank(),legend.position="none",
       panel.background=element_blank(),panel.border=element_blank(),panel.grid.major=element_blank(),
       panel.grid.minor=element_blank(),plot.background=element_blank())+
   ggtitle("OpenAQ data sources with geographical coordinates") +
  theme(plot.title = element_text(lineheight=1, face="bold"))
print(plotMap)

==> ropenaq_0.1.3.tar.gz: ropenaq/inst/doc/mapping_openaq_monitors.R <==
## ---- echo = FALSE, warning=FALSE, message=FALSE-------------------------
NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  purl = NOT_CRAN,
  eval = NOT_CRAN
)

## ---- warning=FALSE, message=FALSE---------------------------------------
library("ggplot2")
library("ropenaq")
library("dplyr")

## ---- warning=FALSE, message=FALSE---------------------------------------
pagee <- 1
dataGeo <- NULL
nrows <- 1000
while(nrows == 1000){
  temp <- aq_locations(page = pagee,
                       limit = 1000)
  nrows <- nrow(temp)
  pagee <- pagee + 1
  dataGeo <- dplyr::bind_rows(dataGeo, temp)
}
dataGeo <- filter(dataGeo, location != "Test Prueba", location != "PA")

## ----fig.width=7, fig.height=4, warning=FALSE, message=FALSE-------------


library("rworldmap")

worldMap <- map_data(map="world")

gg <- ggplot() + geom_map(data=worldMap, map=worldMap,
                          aes(map_id=region, x=long, y=lat),
                          fill = "grey60")
gg

## ----fig.width=7, fig.height=4-------------------------------------------
plotMap <- gg +
  geom_point(data = dataGeo, aes(x=longitude, y=latitude), size=1, col = "#EE9F8E")+
  theme(axis.line=element_blank(),axis.text.x=element_blank(),
       axis.text.y=element_blank(),axis.ticks=element_blank(),
       axis.title.x=element_blank(),
       axis.title.y=element_blank(),legend.position="none",
       panel.background=element_blank(),panel.border=element_blank(),panel.grid.major=element_blank(),
       panel.grid.minor=element_blank(),plot.background=element_blank())+
   ggtitle("OpenAQ data sources with geographical coordinates") +
  theme(plot.title = element_text(lineheight=1, face="bold"))
print(plotMap)
